==> nextcloud-15.0.2-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/gl.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Ligazón:",
    "Password:" : "Contrasinal:",
    "Generating system report failed." : "Produciuse un fallo ao xerar o informe do sistema.",
    "Subscription notifications" : "Notificacións de subscricións",
    "Could not create folder \"System information\" to store generated report." : "Non foi posíbel xerar o cartafol «Información do sistema» para almacenar o informe xerado.",
    "Could not create file \"%s\" to store generated report." : "Non foi posíbel xerar o ficheiro «%s» para almacenar o informe xerado.",
    "Could not share file \"%s\"." : "Non foi posíbel compartir o ficheiro «%s».",
    "Nextcloud Subscription" : "Subscripción a Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "O seu servidor non dispón dunha subscripción a Nextcloud ou a súa subscripción caducou.",
    "Your Nextcloud server subscription does not cover your number of users." : "A súa subscripción do servidor Nextcloud non cubre o seu número de usuarios.",
    "Your Nextcloud Subscription has expired!" : "A súa subscripción a Nextcloud caducou!",
    "Your server has no Nextcloud Subscription" : "O seu servidor non ten unha subscrición a Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "O seu servidor Nextcloud non está protexido por unha subscrición de Nextcloud empresarial.",
    "A Nextcloud Support Subscription means the original developers behind your private cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Unha Subscripción de Asistencia Nextcloud implica que os desenvolvedores originais estarán detrás do seu servidor privado, dedicados 100% ao su éxito: a seguridade, escalabilidade, rendimiento e funcionalidade do seu servizo!",
    "If you encounter a problem and your server does no longer work, blocking employees from sharing or customers from downloading and uploading files, you don't have to rely on searching online and asking volunteers on forums and social media for a solution. You have direct access to our experienced engineers who help you track down and fix the problem." : "Se vostede se atopa cun problema e o seu servidor non funciona, impide que os empregados compartan ou que os clientes descargen e envíen ficheiros, non ten que depender de facer buscas en liña e pedir axuda a voluntarios en foros e redes sociais para atopar unha solución. Vostede ten acceso directo aos nosos experimentados enxeñeiros que o axudarán a atopar e solucionar ao problema.",
    "You have a contract with the vendor providing confidential security information, mitigations, patches and updates." : "Vostede ten un contrato co provedor que fornecerá información confidencial de seguridade, mitigacións, parches e actualizacións.",
    "If you want to skip a release or two and stay a bit longer on your current version without disruptions, you don't have to run software without security updates. We deliver them to you as long as is needed!" : "Se quere omitir unha versión ou dúas e manterse algún tempo máis na súa actual versión sen interrupción, non ten que executar software sen actualizacións de seguridade. Entregámosllelas durante tanto tempo como sexa necesario.",
    "If you have performance and scalability issues you have the best expertise at hand, instead of having to search on the web and hope you find a solution." : "Se ten problemas de rendemento e escalabilidade, ten a man a mellor experiencia, no canto de ter que buscar na web e agardar que haxa unha solución.",
    "If you are asked how the compliance of Nextcloud is and if you can deliver a data export under GDPR, HIPAA or other rules, you have access to the right documentation and can tap into our expertise to respond quickly and accurately." : "Se se lle pregunta como é a conformidade do Nextcloud e se pode facer unha exportación de datos segundo GDPR, HIPAA ou outras regras, ten acceso á documentación correcta e pode aproveitar a nosa experiancia para obter unha resposta rápida e precisa.",
    "We can also provide you Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a very limited form for free. And we can develop further integrations and capabilities you need." : "Tamén podemos fornecerlle integración co Outlook, ofimática en liña, comunicación de voz, vídeo e escrita integrada e escalábel y outras características dispoñíbeis só de xeito moi limitado de balde. E podemos desenvolver máis integracións e funcionalidades que necesite.",
    "A subscription helps you get the most out of Nextcloud! Don't your users deserve the best?" : "Unha subscrición axúdalle a obter o mellor do Nextcloud. Non merecen os seus usuarios o mellor?\n",
    "Learn more now" : "Aprender máis agora",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %1$s porque ten máis de %2$s usuarios rexistrados.",
    "Your Nextcloud server Subscription is over limit" : "A súa subscripción do servidor do Nextcloud está por riba do límite",
    "Dear admin," : "Estimado administrador.",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "A súa subscrición a Nextcloud no cubre o número de usuarios que están activos actualmente neste servidor. Contacte co seu xestor de contas de Nextcloud para actualizar a súa subscrición.",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s é o seu xestor de contas co que pode por correo no enderezo %2$s ou por teléfono no %3$s.\n",
    "Thank you," : "Grazas.",
    "Your Nextcloud team" : "O seu equipo de Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %s porque ten máis usuarios dos cubertos pola subscrición.",
    "Your Nextcloud server Subscription is expired" : "A súa subscripción do servidor do Nextcloud caducou",
    "Your Nextcloud server Subscription is expired!" : "A súa subscripción do servidor do Nextcloud caducou!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "A súa subscrición a Nextcloud caducou! Contacte co seu xestor de contas de Nextcloud para actualizar a sua subscrición.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %s porque a súa subscrición caducou.",
    "Support" : "Asistencia",
    "Getting support and help for your Nextcloud" : "Obtendo asistencia e axuda para o seu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "O aplicativo de aistencia fornecelle acceso directo á axuda e aos recursos de consulta, opcións de contacto dedicado co seu xestor de contas e unha vista xeral da súa subscrición empresarial.",
    "Basic subscription" : "Subscrición básica",
    "Standard subscription" : "Subscrición estándar",
    "Premium subscription" : "Subscrición premium",
    "Géant subscription" : "Subscrición xigante",
    "Silver partner subscription" : "Subscrición de patrocinador prata",
    "Gold partner subscription" : "Subscrición de patrocinador ouro",
    "Subscription" : "Subscrición",
    "Over subscription limit" : "Superouse o límite de subscrición",
    "Valid subscription" : "Subscrición valida",
    "Expired subscription" : "Subscrición caducada",
    "Subscription key:" : "Chave da suscrición:",
    "_Expires in %n year_::_Expires in %n years_" : ["Caduca nun ano","Caduca en %n anos"],
    "_Expires in %n month_::_Expires in %n months_" : ["Caduca nun mes","Caduca en %n meses"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Caduca nunha semana","Caduca en %n semanas"],
    "_Expires in %n day_::_Expires in %n days_" : ["Caduca nun día","Caduca en %n días"],
    "_For %n users_::_For %n users_" : ["Para un usuario","Para %n usuarios"],
    "_currently at %n user_::_currently at %n users_" : ["%n usuario actualmente","%n usuarios actualmente"],
    "Includes support for %s" : "Inclúe asistencia para %s",
    "Includes support for %1$s & %2$s" : "Inclúe asistencia para %1$s e %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclúe asistencia para %1$s, %2$s e %3$s",
    "Update subscription key" : "Actualizar a chave de subscripción",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s é o seu xestor de contas. Non dubide en contactar con nós se ten algunha dúbida sobre a súa subscrición.",
    "You can find answers to common question in our portal and also file support requests there." : "Pode atopar respostas a preguntas habituais no noso portal e tamén presentar aí as peticións de asistencia.",
    "Access Nextcloud portal" : "Acceder ao portal do Nexcloud",
    "System information" : "Información do sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recoller información do sistema para a asistencia. O botón embaixo xera un ficheiro de texto no cartafol «Información do sistema» e comparte como ligazón pública protexida por contrasinal. A ligazón é válida durante dúas semanas",
    "Generate system report" : "Xerar un informe do sistema",
    "Enterprise subscription recommended" : "Recomendase a subscrición empresarial",
    "No active enterprise subscription" : "Non hai ningunha subscición empresarial activa",
    "Unsupported" : "Non admitido",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor do Nexcloud non dispón dunha subscición empresarial.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Unha subscrición empresarial a Nexcloud axúdalle a obter o máximo rendemento do seu Nextcloud, manter os seus datos seguros e a fiabilidade no funcionamento do seu servidor.",
    "Advantages" : "Vantaxes",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acceso á experiencia técnica dos desenvolvedores do Nextcloud a través da documentación e da asistencia",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acceso a funcionalidades adicionais como a integración co Outlook, ofimática en liña e máis",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acceso á experiencia en escalabilidade e funcionalidades de escalabilidade para as os aplicativos Files e Talk",
    "Optional branding, consulting, architecture advice" : "Opcionalmente pode acceder a asesoría sobre promoción da marca, consultoría e consellos sobre arquitectura",
    "Confidential security notification service, mitigations, patches and advice" : "Servizo de notificacións confidenciais de seguridad, mitigacións, parches e consellos",
    "Compliance certification, advice and documentation" : "Certificación de conformidade, consellos e documentación",
    "Get a quote" : "Solicitar un orzamento",
    "More information" : "Máis información",
    "Subscription benefits" : "Beneficios da subscrición",
    "Pricing" : "Prezo",
    "Commmunity support" : "Asistencia da comunidade",
    "Forum" : "Foro",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud é software libre e está asistido por unha comunidade moi activa. Rexístrese no foro para facer preguntas e debater con outros.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud emprega GitHub como plataforma para traballar colaborativamente. Pode cubrir os informes de erro alí directamente.",
    "Chat" : "Conversa",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Conversa con nós na nosa canle do IRC #nextcloud en Freenode.",
    "Nextcloud forum" : "Foro do Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud no GitHub",
    "Open chat" : "Abrir unha conversa",
    "Subscription key" : "Chave de suscrición",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Se vostede ten unha subscrición activa a Nextcloud, introduza aquí a súa chave de subscrición.",
    "Learn more about an enterprise subscription." : "Saiba máis sobre a subscrición empresarial.",
    "Set subscription key" : "Estabelecer a chave de subscripción",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Non foi posíbel recuperar correctamente a información da subscrición. Programouse outra tentativa. Compróbeo maís tarde.\n",
    "The subscription key was invalid." : "A chave de subscripción non é válida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Non foi posíbel verificar a chave de subscrición porque este servidor non ten conexión a internet. Póñase en contacto co equipo de asistencia para solucionar isto.",
    "The subscription key had an invalid format." : "A chave de subscrición ten un formato incorrecto.",
    "While fetching the subscription information an error happened." : "Produciuse un erro mentres se recuperaba a información da subscrición.",
    "News" : "Novas",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para obter información actualizada de que está acontecendo co Nextcloud, rexístrese no boletín e siga as nosas contas nos medios sociais.",
    "Follow us on Google+" : "Síganos no Google+",
    "Like our Facebook page" : "Faga un Gústame na nosa páxina de Facebook",
    "Follow us on Twitter" : "Síganos no Twitter",
    "Check out our blog" : "Visite o noso blog",
    "Subscribe to our newsletter" : "Subscríbase ao noso boletín"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-15.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/support/l10n/gl.js <==
OC.L10N.register(
    "support",
    {
    "Link:" : "Ligazón:",
    "Password:" : "Contrasinal:",
    "Generating system report failed." : "Produciuse un fallo ao xerar o informe do sistema.",
    "Subscription notifications" : "Notificacións de subscricións",
    "Could not create folder \"System information\" to store generated report." : "Non foi posíbel xerar o cartafol «Información do sistema» para almacenar o informe xerado.",
    "Could not create file \"%s\" to store generated report." : "Non foi posíbel xerar o ficheiro «%s» para almacenar o informe xerado.",
    "Could not share file \"%s\"." : "Non foi posíbel compartir o ficheiro «%s».",
    "Nextcloud Subscription" : "Subscripción a Nextcloud",
    "Your server has no Nextcloud Subscription or your Subscription has expired." : "O seu servidor non dispón dunha subscripción a Nextcloud ou a súa subscripción caducou.",
    "Your Nextcloud server subscription does not cover your number of users." : "A súa subscripción do servidor Nextcloud non cubre o seu número de usuarios.",
    "Your Nextcloud Subscription has expired!" : "A súa subscripción a Nextcloud caducou!",
    "Your server has no Nextcloud Subscription" : "O seu servidor non ten unha subscrición a Nextcloud",
    "Your Nextcloud server is not backed by a Nextcloud Enterprise Subscription." : "O seu servidor Nextcloud non está protexido por unha subscrición de Nextcloud empresarial.",
    "A Nextcloud Enterprise Subscription means the original developers behind your self-hosted cloud server are 100% dedicated to your success: the security, scalability, performance and functionality of your service!" : "Unha Subscrición de Asistencia Empresarial do Nextcloud implica que os desenvolvedores orixinais estarán detrás do seu servidor autohospedado, dedicados 100% ao seu éxito: a seguridade, escalabilidade, rendemento e funcionalidade do seu servizo!",
    "If your server setup breaks and employees can't work anymore, you don't have to rely on searching online forums for a solution. You have direct access to our experienced engineers!" : "Se a configuración do servidor racha e os empregados non poden traballar, non necesita confiar na busca de foros en liña para obter unha solución. Teña acceso directo aos nosos experimentados enxeñeiros.",
    "You have a contract with the vendor providing early security information, mitigations, patches and updates." : "Vostede ten un contrato co provedor que fornecerá información precoz da seguridade, mitigacións, parches e actualizacións.",
    "If you need to stay longer on your current version without disruptions, you don't have to run software without security updates." : "Se quere manterse algún tempo máis na súa actual versión sen interrupción, non ten que executar software sen actualizacións de seguridade. ",
    "You have the best expertise at hand to deal with performance and scalability issues." : "Ten a mellor experiencia dispoñíbel para xestionar incidentes de rendemento e escalabilidade.",
    "You have access to the right documentation and expertise to quickly answer compliance questions or deliver on GDPR, HIPAA and other regulation requirements." : "Ten acceso á documentación e coñecementos axeitados para responder rapidamente ás preguntas de cumprimento ou para cumprir cos requisitos GDPR, HIPAA e outros requisitos regulamentarios.",
    "We can also provide Outlook integration, Online Office, scalable integrated audio-video and chat communication an other features only available in a limited form for free or develop further integrations and capabilities to you needs." : "Tamén podemos fornecerlle a integración co Outlook, Office en liña, comunicación integrada de son e video escalábel e outras funcións que só están dispoñíbeis de forma limitada de balde ou desenvolver máis integracións e capacidades ás súas necesidades.",
    "A subscription helps you get the most out of Nextcloud!" : "Unha subscrición axúdalle a obter o mellor do Nextcloud!",
    "Learn more now" : "Aprender máis agora",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %1$s because you have over %2$s registered users." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %1$s porque ten máis de %2$s usuarios rexistrados.",
    "Your Nextcloud server Subscription is over limit" : "A súa subscripción do servidor do Nextcloud está por riba do límite",
    "Dear admin," : "Estimado administrador.",
    "Your Nextcloud Subscription doesn't cover the number of users who are currently active on this server. Please contact you Nextcloud account manager to get your subscription updated!" : "A súa subscrición a Nextcloud no cubre o número de usuarios que están activos actualmente neste servidor. Contacte co seu xestor de contas de Nextcloud para actualizar a súa subscrición.",
    "%1$s is your account manager and can be reached by email via %2$s or by phone via %3$s." : "%1$s é o seu xestor de contas co que pode por correo no enderezo %2$s ou por teléfono no %3$s.\n",
    "Thank you," : "Grazas.",
    "Your Nextcloud team" : "O seu equipo de Nextcloud",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because you have more users than what your subscription covers." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %s porque ten máis usuarios dos cubertos pola subscrición.",
    "Your Nextcloud server Subscription is expired" : "A súa subscripción do servidor do Nextcloud caducou",
    "Your Nextcloud server Subscription is expired!" : "A súa subscripción do servidor do Nextcloud caducou!",
    "Your Nextcloud Subscription has expired! Please contact you Nextcloud account manager to get your subscription updated!" : "A súa subscrición a Nextcloud caducou! Contacte co seu xestor de contas de Nextcloud para actualizar a sua subscrición.",
    "This mail was sent to all administrators by the support app on your Nextcloud instance at %s because your subscription expired." : "Este correo foi enviado a todos os administradores polo aplicativo de asistencia na súa instancia do Nextcloud en %s porque a súa subscrición caducou.",
    "Support" : "Asistencia",
    "Getting support and help for your Nextcloud" : "Obtendo asistencia e axuda para o seu Nextcloud",
    "The support app covers you with direct access to help and consulting resources, dedicated contact options to your account manager and an overview of your enterprise subscription." : "O aplicativo de aistencia fornecelle acceso directo á axuda e aos recursos de consulta, opcións de contacto dedicado co seu xestor de contas e unha vista xeral da súa subscrición empresarial.",
    "Basic subscription" : "Subscrición básica",
    "Standard subscription" : "Subscrición estándar",
    "Premium subscription" : "Subscrición premium",
    "Géant subscription" : "Subscrición xigante",
    "Silver partner subscription" : "Subscrición de patrocinador prata",
    "Gold partner subscription" : "Subscrición de patrocinador ouro",
    "Subscription" : "Subscrición",
    "Over subscription limit" : "Superouse o límite de subscrición",
    "Valid subscription" : "Subscrición valida",
    "Expired subscription" : "Subscrición caducada",
    "Subscription key:" : "Chave da suscrición:",
    "_Expires in %n year_::_Expires in %n years_" : ["Caduca nun ano","Caduca en %n anos"],
    "_Expires in %n month_::_Expires in %n months_" : ["Caduca nun mes","Caduca en %n meses"],
    "_Expires in %n week_::_Expires in %n weeks_" : ["Caduca nunha semana","Caduca en %n semanas"],
    "_Expires in %n day_::_Expires in %n days_" : ["Caduca nun día","Caduca en %n días"],
    "_For %n users_::_For %n users_" : ["Para un usuario","Para %n usuarios"],
    "_currently at %n user_::_currently at %n users_" : ["%n usuario actualmente","%n usuarios actualmente"],
    "Includes support for %s" : "Inclúe asistencia para %s",
    "Includes support for %1$s & %2$s" : "Inclúe asistencia para %1$s e %2$s",
    "Includes support for %1$s, %2$s & %3$s" : "Inclúe asistencia para %1$s, %2$s e %3$s",
    "Update subscription key" : "Actualizar a chave de subscripción",
    "%s is your account manager. Don't hesitate to reach out to us if you have questions regarding your subscription." : "%s é o seu xestor de contas. Non dubide en contactar con nós se ten algunha dúbida sobre a súa subscrición.",
    "You can find answers to common question in our portal and also file support requests there." : "Pode atopar respostas a preguntas habituais no noso portal e tamén presentar aí as peticións de asistencia.",
    "Access Nextcloud portal" : "Acceder ao portal do Nexcloud",
    "System information" : "Información do sistema",
    "Collect system information for support cases. The button below generates a text file in the folder \"System information\" and shares it as password protected public link. The link is valid for 2 weeks." : "Recoller información do sistema para a asistencia. O botón embaixo xera un ficheiro de texto no cartafol «Información do sistema» e comparte como ligazón pública protexida por contrasinal. A ligazón é válida durante dúas semanas",
    "Generate system report" : "Xerar un informe do sistema",
    "Enterprise subscription recommended" : "Recomendase a subscrición empresarial",
    "No active enterprise subscription" : "Non hai ningunha subscición empresarial activa",
    "Unsupported" : "Non admitido",
    "This Nextcloud server has no Enterprise Subscription." : "Este servidor do Nexcloud non dispón dunha subscición empresarial.",
    "A Nextcloud Enterprise Subscription helps you get the most out of your Nextcloud, keep your data secure and your server working reliably at all times." : "Unha subscrición empresarial a Nexcloud axúdalle a obter o máximo rendemento do seu Nextcloud, manter os seus datos seguros e a fiabilidade no funcionamento do seu servidor.",
    "Advantages" : "Vantaxes",
    "Access to the technical expertise of the Nextcloud developers through documentation and support" : "Acceso á experiencia técnica dos desenvolvedores do Nextcloud a través da documentación e da asistencia",
    "Access to additional capabilities like Outlook integration, online office and more" : "Acceso a funcionalidades adicionais como a integración co Outlook, ofimática en liña e máis",
    "Access to scalability expertise and scalability capabilities for Files and Talk" : "Acceso á experiencia en escalabilidade e funcionalidades de escalabilidade para as os aplicativos Files e Talk",
    "Optional branding, consulting, architecture advice" : "Opcionalmente pode acceder a asesoría sobre promoción da marca, consultoría e consellos sobre arquitectura",
    "Confidential security notification service, mitigations, patches and advice" : "Servizo de notificacións confidenciais de seguridad, mitigacións, parches e consellos",
    "Compliance certification, advice and documentation" : "Certificación de conformidade, consellos e documentación",
    "Get a quote" : "Solicitar un orzamento",
    "More information" : "Máis información",
    "Subscription benefits" : "Beneficios da subscrición",
    "Pricing" : "Prezo",
    "Commmunity support" : "Asistencia da comunidade",
    "Forum" : "Foro",
    "Nextcloud is free software which is supported by a very active community. Please register at the forum to ask questions and discuss with others." : "Nextcloud é software libre e está asistido por unha comunidade moi activa. Rexístrese no foro para facer preguntas e debater con outros.",
    "GitHub" : "GitHub",
    "Nextcloud uses GitHub as platform to collaboratively work. You can file bug reports directly there." : "Nextcloud emprega GitHub como plataforma para traballar colaborativamente. Pode cubrir os informes de erro alí directamente.",
    "Chat" : "Conversa",
    "Chat with us on our IRC channel #nextcloud on Freenode." : "Conversa con nós na nosa canle do IRC #nextcloud en Freenode.",
    "Nextcloud forum" : "Foro do Nextcloud",
    "Nextcloud at GitHub" : "Nextcloud no GitHub",
    "Open chat" : "Abrir unha conversa",
    "Subscription key" : "Chave de suscrición",
    "If you have an active Nextcloud Subscription please enter your subscription key here." : "Se vostede ten unha subscrición activa a Nextcloud, introduza aquí a súa chave de subscrición.",
    "Learn more about an enterprise subscription." : "Saiba máis sobre a subscrición empresarial.",
    "Set subscription key" : "Estabelecer a chave de subscripción",
    "The subscription info could not properly fetched right now. A retry is scheduled. Please check back later." : "Non foi posíbel recuperar correctamente a información da subscrición. Programouse outra tentativa. Compróbeo maís tarde.\n",
    "The subscription key was invalid." : "A chave de subscripción non é válida.",
    "The subscription key could not be verified, because this server has no internet connection. Please reach out to the support team to get this resolved." : "Non foi posíbel verificar a chave de subscrición porque este servidor non ten conexión a internet. Póñase en contacto co equipo de asistencia para solucionar isto.",
    "The subscription key had an invalid format." : "A chave de subscrición ten un formato incorrecto.",
    "While fetching the subscription information an error happened." : "Produciuse un erro mentres se recuperaba a información da subscrición.",
    "News" : "Novas",
    "To get up to date information what is going on at Nextcloud sign up for the newsletter and follow us on our social media accounts." : "Para obter información actualizada de que está acontecendo co Nextcloud, rexístrese no boletín e siga as nosas contas nos medios sociais.",
    "Follow us on Google+" : "Síganos no Google+",
    "Like our Facebook page" : "Faga un Gústame na nosa páxina de Facebook",
    "Follow us on Twitter" : "Síganos no Twitter",
    "Check out our blog" : "Visite o noso blog",
    "Subscribe to our newsletter" : "Subscríbase ao noso boletín"
},
"nplurals=2; plural=(n != 1);");
